[![PyPI version](https://badge.fury.io/py/sconce-scms.svg)](https://badge.fury.io/py/sconce-scms)

# SCONCE-SCMS
## Spherical and Conic Cosmic Web Finders with Extended SCMS Algorithms


* Free software: MIT license
* Documentation: https://sconce-scms.readthedocs.io.


Installation
--------

To install the latest version of ```sconce-scms``` from this repository, run:

```
python setup.py install
```

To pip install a stable release, run:
```
pip install sconce-scms
```

